@@ -1,8 +1,13 @@
 use std::{env, fs};
+use std::process::exit;
 
 fn main() {
     let args: Vec<String> = env::args().collect();
 
+    if args.len() != 3 {
+        eprintln!("Expected 3 arguments");
+        std::process::exit(69);
+    }
     let phrase = &args[1];
     let replace = &args[2];
     let filename = &args[3];
@@ -12,8 +17,6 @@ fn main() {
     let contents = fs::read_to_string(filename)
         .expect("Something went wrong reading the file");
 
-    println!("With text:\n{}", &contents);
-
     println!("Searching for {}", &phrase);
     println!("In file {}", filename);
 
